---
name: blurb feature request/bug
about: Feature request or bug related to blurb (command line tool)
---

<!--
Request new feature or report a bug with Blurb (command line tool)

For blurb-it GitHub App, go to https://github.com/python/blurb_it

-->

# The short story

It would be nice if ...

# Long version

...

Thanks for blurb!
